==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/ja.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU情報が利用できません",
    "Load average" : "ロードアベレージ",
    "Last minute" : "直近",
    "Memory info not available" : "メモリ情報が利用できません",
    "Total" : "合計",
    "Current usage" : "現在の利用量",
    "Users" : "ユーザー",
    "Groups" : "グループ",
    "Links" : "リンク",
    "Federated sent" : "統合送信",
    "Federated received" : "統合受信",
    "Last 24 hours" : "24時間以内",
    "Last 1 hour" : "1時間以内",
    "Last 5 mins" : "5分以内",
    "Copy" : "コピー",
    "Copied!" : "コピー完了",
    "Not supported!" : "未対応",
    "Press ⌘-C to copy." : "⌘-C でコピーします。",
    "Press Ctrl-C to copy." : "Ctrl-Cを押してコピーします。",
    "Monitoring" : "モニタリング",
    "Monitoring app with useful server information" : "有用なサーバー情報でアプリケーションを監視する",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "CPU負荷、メモリ使用量、ディスク使用量、ユーザー数などの役に立つサーバー情報を提供します。",
    "CPU load" : "CPU負荷",
    "Memory usage" : "メモリ使用量",
    "Active users" : "アクティブユーザー数",
    "Shares" : "共有数",
    "Storage" : "ストレージ",
    "Users:" : "ユーザー数:",
    "Files:" : "ファイル数:",
    "Storages:" : "ストレージ：",
    "Free Space:" : "フリースペース：",
    "Nextcloud" : "Nextcloud",
    "Version:" : "バージョン:",
    "Apps installed:" : "インストールされているアプリケーション：",
    "Apps updates available:" : "利用可能なアプリのアップデート：",
    "PHP" : "PHP",
    "Memory Limit:" : "メモリ制限:",
    "Max Execution Time:" : "最大実行時間:",
    "Upload max size:" : "最大アップロードサイズ:",
    "Database" : "データベース",
    "Type:" : "タイプ:",
    "Size:" : "サイズ:",
    "External monitoring tool" : "外部モニタリングツール",
    "You can connect an external monitoring tool by using this end point:" : "このエンドポイントを利用して外部モニタリングツールに接続することが可能です：",
    "Did you know?" : "知ってますか？",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "URLの最後に \"?format=json\" を追加すると、JSON形式の結果が得られます。",
    "You can connect an external monitoring tool by using this end point: " : "このエンドポイントを利用して外部モニタリングツールに接続することが可能です："
},
"nplurals=1; plural=0;");

==> nextcloud-15.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/ja.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU情報が利用できません",
    "Load average" : "ロードアベレージ",
    "Last minute" : "直近",
    "Memory info not available" : "メモリ情報が利用できません",
    "Total" : "合計",
    "Current usage" : "現在の利用量",
    "Users" : "ユーザー",
    "Groups" : "グループ",
    "Links" : "リンク",
    "Federated sent" : "統合送信",
    "Federated received" : "統合受信",
    "Last 24 hours" : "24時間以内",
    "Last 1 hour" : "1時間以内",
    "Last 5 mins" : "5分以内",
    "Copy" : "コピー",
    "Copied!" : "コピー完了",
    "Not supported!" : "未対応",
    "Press ⌘-C to copy." : "⌘-C でコピーします。",
    "Press Ctrl-C to copy." : "Ctrl-Cを押してコピーします。",
    "Monitoring" : "モニタリング",
    "Monitoring app with useful server information" : "有用なサーバー情報でアプリケーションを監視する",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "CPU負荷、メモリ使用量、ディスク使用量、ユーザー数などの役に立つサーバー情報を提供します。",
    "CPU load" : "CPU負荷",
    "Memory usage" : "メモリ使用量",
    "Active users" : "アクティブユーザー数",
    "Shares" : "共有数",
    "Storage" : "ストレージ",
    "Users:" : "ユーザー数:",
    "Files:" : "ファイル数:",
    "Storages:" : "ストレージ：",
    "Free Space:" : "空き容量：",
    "Nextcloud" : "Nextcloud",
    "Version:" : "バージョン:",
    "Apps installed:" : "インストール済みアプリケーション：",
    "Apps updates available:" : "利用可能なアプリのアップデート：",
    "PHP" : "PHP",
    "Memory Limit:" : "メモリ制限:",
    "Max Execution Time:" : "最大実行時間:",
    "Upload max size:" : "最大アップロードサイズ:",
    "Database" : "データベース",
    "Type:" : "タイプ:",
    "Size:" : "サイズ:",
    "External monitoring tool" : "外部モニタリングツール",
    "You can connect an external monitoring tool by using this end point:" : "このエンドポイントを利用して外部モニタリングツールに接続することが可能です：",
    "Did you know?" : "知ってますか？",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "URLの最後に \"?format=json\" を追加すると、JSON形式の結果が得られます。"
},
"nplurals=1; plural=0;");
